@@ -14,10 +14,10 @@ rm(fam)
 # Compare BLUP vs gBLUP
 test1 = mixed(y=YLD,random=~ID+Block,fixed=~Year+Row+Col,data=Obs,X=list(ID=Gen))
 test2 = mixed(y=YLD,random=~ID+Block,fixed=~Year+Row+Col,data=Obs)
-cor(test1$coef$random$ID,test2$coef$random$ID)
+cor(test1$Coefficients$ID,test2$Coefficients$ID)
 
 # Plot
 par(mfrow=c(1,3))
-plot(test1$hat,Obs$YLD,main='Goodness of fit',xlab='Fitted',ylab='Observed',pch=20)
-plot(test1$coef$random$ID,main='Genomic fit',test2$coef$random$ID,xlab='GEBV',ylab='BLUP',pch=20)
-plot(test1$coef$markers$ID,main='Marker Effects',ylab='Effect',xlab='SNP',pch=20)
\ No newline at end of file
+plot(test1$Fitness$hat,test1$Fitness$obs,main='Goodness of fit',xlab='Fitted',ylab='Observed',pch=20)
+plot(test1$Coefficients$ID,main='Genomic fit',test2$Coefficients$ID,xlab='GEBV',ylab='BLUP',pch=20)
+plot(test1$Structure$ID,main='Marker Effects',ylab='Effect',xlab='SNP',pch=20)
